@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2005-2020, PyInstaller Development Team.
+# Copyright (c) 2005-2022, PyInstaller Development Team.
 #
 # Distributed under the terms of the GNU General Public License (version 2
 # or later) with exception for distributing the bootloader.
@@ -21,7 +21,7 @@ distribution metadata from json files located in the ``conda-meta`` directory.
 This module is available only if run inside a Conda environment. Usage of this module should therefore be wrapped in
 a conditional clause::
 
-    from PyInstaller.utils.hooks import is_pure_conda
+    from PyInstaller.compat import is_pure_conda
 
     if is_pure_conda:
         from PyInstaller.utils.hooks import conda_support
@@ -65,7 +65,7 @@ for _path in sys.path:
 PYTHONPATH_PREFIXES.sort(key=lambda p: len(p.parts), reverse=True)
 
 
-class Distribution(object):
+class Distribution:
     """
     A bucket class representation of a Conda distribution.
 
